@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="api_error.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -26,6 +26,7 @@
 import pprint
 import re  # noqa: F401
 
+import datetime
 import six
 import json
 
@@ -82,7 +83,7 @@ class ApiError(object):
     def code(self):
         """Gets the code of this ApiError.  # noqa: E501
 
-        Gets or sets api error code.  # noqa: E501
+        Gets or sets the API error code.  # noqa: E501
 
         :return: The code of this ApiError.  # noqa: E501
         :rtype: str
@@ -93,7 +94,7 @@ class ApiError(object):
     def code(self, code):
         """Sets the code of this ApiError.
 
-        Gets or sets api error code.  # noqa: E501
+        Gets or sets the API error code.  # noqa: E501
 
         :param code: The code of this ApiError.  # noqa: E501
         :type: str
@@ -104,7 +105,7 @@ class ApiError(object):
     def date_time(self):
         """Gets the date_time of this ApiError.  # noqa: E501
 
-        Gets or sets server datetime.  # noqa: E501
+        Gets or sets the server DateTime.  # noqa: E501
 
         :return: The date_time of this ApiError.  # noqa: E501
         :rtype: datetime
@@ -115,7 +116,7 @@ class ApiError(object):
     def date_time(self, date_time):
         """Sets the date_time of this ApiError.
 
-        Gets or sets server datetime.  # noqa: E501
+        Gets or sets the server DateTime.  # noqa: E501
 
         :param date_time: The date_time of this ApiError.  # noqa: E501
         :type: datetime
@@ -126,7 +127,7 @@ class ApiError(object):
     def description(self):
         """Gets the description of this ApiError.  # noqa: E501
 
-        Gets or sets error description.  # noqa: E501
+        Gets or sets the error description.  # noqa: E501
 
         :return: The description of this ApiError.  # noqa: E501
         :rtype: str
@@ -137,7 +138,7 @@ class ApiError(object):
     def description(self, description):
         """Sets the description of this ApiError.
 
-        Gets or sets error description.  # noqa: E501
+        Gets or sets the error description.  # noqa: E501
 
         :param description: The description of this ApiError.  # noqa: E501
         :type: str
@@ -148,7 +149,7 @@ class ApiError(object):
     def inner_error(self):
         """Gets the inner_error of this ApiError.  # noqa: E501
 
-        Gets or sets inner error.  # noqa: E501
+        Gets or sets the inner error.  # noqa: E501
 
         :return: The inner_error of this ApiError.  # noqa: E501
         :rtype: ApiError
@@ -159,7 +160,7 @@ class ApiError(object):
     def inner_error(self, inner_error):
         """Sets the inner_error of this ApiError.
 
-        Gets or sets inner error.  # noqa: E501
+        Gets or sets the inner error.  # noqa: E501
 
         :param inner_error: The inner_error of this ApiError.  # noqa: E501
         :type: ApiError
@@ -170,7 +171,7 @@ class ApiError(object):
     def message(self):
         """Gets the message of this ApiError.  # noqa: E501
 
-        Gets or sets error message.  # noqa: E501
+        Gets or sets the error message.  # noqa: E501
 
         :return: The message of this ApiError.  # noqa: E501
         :rtype: str
@@ -181,7 +182,7 @@ class ApiError(object):
     def message(self, message):
         """Sets the message of this ApiError.
 
-        Gets or sets error message.  # noqa: E501
+        Gets or sets the error message.  # noqa: E501
 
         :param message: The message of this ApiError.  # noqa: E501
         :type: str
@@ -195,21 +196,25 @@ class ApiError(object):
 
         for attr, _ in six.iteritems(self.swagger_types):
             value = getattr(self, attr)
+            if value is None:
+                continue
             if isinstance(value, list):
-                result[attr] = list(map(
+                result[self.attribute_map[attr]] = list(map(
                     lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                     value
                 ))
             elif hasattr(value, "to_dict"):
-                result[attr] = value.to_dict()
+                result[self.attribute_map[attr]] = value.to_dict()
             elif isinstance(value, dict):
-                result[attr] = dict(map(
+                result[self.attribute_map[attr]] = dict(map(
                     lambda item: (item[0], item[1].to_dict())
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
-                result[attr] = value
+                result[self.attribute_map[attr]] = value
 
         return result
 
@@ -232,6 +237,8 @@ class ApiError(object):
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
                 result[self.attribute_map[attr]] = value
 
