@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="form_field.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -26,6 +26,7 @@
 import pprint
 import re  # noqa: F401
 
+import datetime
 import six
 import json
 
@@ -112,7 +113,7 @@ class FormField(object):
     def link(self):
         """Gets the link of this FormField.  # noqa: E501
 
-        Gets or sets link to the document.  # noqa: E501
+        Gets or sets the link to the document.  # noqa: E501
 
         :return: The link of this FormField.  # noqa: E501
         :rtype: WordsApiLink
@@ -123,7 +124,7 @@ class FormField(object):
     def link(self, link):
         """Sets the link of this FormField.
 
-        Gets or sets link to the document.  # noqa: E501
+        Gets or sets the link to the document.  # noqa: E501
 
         :param link: The link of this FormField.  # noqa: E501
         :type: WordsApiLink
@@ -134,7 +135,7 @@ class FormField(object):
     def node_id(self):
         """Gets the node_id of this FormField.  # noqa: E501
 
-        Gets or sets node id.  # noqa: E501
+        Gets or sets the node id.  # noqa: E501
 
         :return: The node_id of this FormField.  # noqa: E501
         :rtype: str
@@ -145,7 +146,7 @@ class FormField(object):
     def node_id(self, node_id):
         """Sets the node_id of this FormField.
 
-        Gets or sets node id.  # noqa: E501
+        Gets or sets the node id.  # noqa: E501
 
         :param node_id: The node_id of this FormField.  # noqa: E501
         :type: str
@@ -156,7 +157,7 @@ class FormField(object):
     def calculate_on_exit(self):
         """Gets the calculate_on_exit of this FormField.  # noqa: E501
 
-        Gets or sets true if references to the specified form field are automatically updated whenever the field is exited.  # noqa: E501
+        Gets or sets a value indicating whether references to the specified form field are automatically updated whenever the field is exited.  # noqa: E501
 
         :return: The calculate_on_exit of this FormField.  # noqa: E501
         :rtype: bool
@@ -167,7 +168,7 @@ class FormField(object):
     def calculate_on_exit(self, calculate_on_exit):
         """Sets the calculate_on_exit of this FormField.
 
-        Gets or sets true if references to the specified form field are automatically updated whenever the field is exited.  # noqa: E501
+        Gets or sets a value indicating whether references to the specified form field are automatically updated whenever the field is exited.  # noqa: E501
 
         :param calculate_on_exit: The calculate_on_exit of this FormField.  # noqa: E501
         :type: bool
@@ -178,7 +179,7 @@ class FormField(object):
     def enabled(self):
         """Gets the enabled of this FormField.  # noqa: E501
 
-        Gets or sets true if a form field is enabled.  # noqa: E501
+        Gets or sets a value indicating whether a form field is enabled.  # noqa: E501
 
         :return: The enabled of this FormField.  # noqa: E501
         :rtype: bool
@@ -189,7 +190,7 @@ class FormField(object):
     def enabled(self, enabled):
         """Sets the enabled of this FormField.
 
-        Gets or sets true if a form field is enabled.  # noqa: E501
+        Gets or sets a value indicating whether a form field is enabled.  # noqa: E501
 
         :param enabled: The enabled of this FormField.  # noqa: E501
         :type: bool
@@ -200,7 +201,7 @@ class FormField(object):
     def entry_macro(self):
         """Gets the entry_macro of this FormField.  # noqa: E501
 
-        Gets or sets returns or sets an entry macro name for the form field.  # noqa: E501
+        Gets or sets the entry macro name for the form field.  # noqa: E501
 
         :return: The entry_macro of this FormField.  # noqa: E501
         :rtype: str
@@ -211,7 +212,7 @@ class FormField(object):
     def entry_macro(self, entry_macro):
         """Sets the entry_macro of this FormField.
 
-        Gets or sets returns or sets an entry macro name for the form field.  # noqa: E501
+        Gets or sets the entry macro name for the form field.  # noqa: E501
 
         :param entry_macro: The entry_macro of this FormField.  # noqa: E501
         :type: str
@@ -222,7 +223,7 @@ class FormField(object):
     def exit_macro(self):
         """Gets the exit_macro of this FormField.  # noqa: E501
 
-        Gets or sets returns or sets an exit macro name for the form field.  # noqa: E501
+        Gets or sets the exit macro name for the form field.  # noqa: E501
 
         :return: The exit_macro of this FormField.  # noqa: E501
         :rtype: str
@@ -233,7 +234,7 @@ class FormField(object):
     def exit_macro(self, exit_macro):
         """Sets the exit_macro of this FormField.
 
-        Gets or sets returns or sets an exit macro name for the form field.  # noqa: E501
+        Gets or sets the exit macro name for the form field.  # noqa: E501
 
         :param exit_macro: The exit_macro of this FormField.  # noqa: E501
         :type: str
@@ -244,7 +245,7 @@ class FormField(object):
     def help_text(self):
         """Gets the help_text of this FormField.  # noqa: E501
 
-        Gets or sets returns or sets the text that's displayed in a message box when the form field has the focus and the user presses F1.  # noqa: E501
+        Gets or sets text, displayed in a message box when the form field has the focus and the user presses F1.  # noqa: E501
 
         :return: The help_text of this FormField.  # noqa: E501
         :rtype: str
@@ -255,7 +256,7 @@ class FormField(object):
     def help_text(self, help_text):
         """Sets the help_text of this FormField.
 
-        Gets or sets returns or sets the text that's displayed in a message box when the form field has the focus and the user presses F1.  # noqa: E501
+        Gets or sets text, displayed in a message box when the form field has the focus and the user presses F1.  # noqa: E501
 
         :param help_text: The help_text of this FormField.  # noqa: E501
         :type: str
@@ -288,7 +289,7 @@ class FormField(object):
     def own_help(self):
         """Gets the own_help of this FormField.  # noqa: E501
 
-        Gets or sets specifies the source of the text that's displayed in a message box when a form field has the focus and the user presses F1.  # noqa: E501
+        Gets or sets a value indicating whether the source of the text that's displayed in a message box when a form field has the focus and the user presses F1.  # noqa: E501
 
         :return: The own_help of this FormField.  # noqa: E501
         :rtype: bool
@@ -299,7 +300,7 @@ class FormField(object):
     def own_help(self, own_help):
         """Sets the own_help of this FormField.
 
-        Gets or sets specifies the source of the text that's displayed in a message box when a form field has the focus and the user presses F1.  # noqa: E501
+        Gets or sets a value indicating whether the source of the text that's displayed in a message box when a form field has the focus and the user presses F1.  # noqa: E501
 
         :param own_help: The own_help of this FormField.  # noqa: E501
         :type: bool
@@ -310,7 +311,7 @@ class FormField(object):
     def own_status(self):
         """Gets the own_status of this FormField.  # noqa: E501
 
-        Gets or sets specifies the source of the text that's displayed in the status bar when a form field has the focus.  # noqa: E501
+        Gets or sets a value indicating whether the source of the text that's displayed in the status bar when a form field has the focus.  # noqa: E501
 
         :return: The own_status of this FormField.  # noqa: E501
         :rtype: bool
@@ -321,7 +322,7 @@ class FormField(object):
     def own_status(self, own_status):
         """Sets the own_status of this FormField.
 
-        Gets or sets specifies the source of the text that's displayed in the status bar when a form field has the focus.  # noqa: E501
+        Gets or sets a value indicating whether the source of the text that's displayed in the status bar when a form field has the focus.  # noqa: E501
 
         :param own_status: The own_status of this FormField.  # noqa: E501
         :type: bool
@@ -332,7 +333,7 @@ class FormField(object):
     def status_text(self):
         """Gets the status_text of this FormField.  # noqa: E501
 
-        Gets or sets returns or sets the text that's displayed in the status bar when a form field has the focus.  # noqa: E501
+        Gets or sets text, displayed in the status bar when a form field has the focus.  # noqa: E501
 
         :return: The status_text of this FormField.  # noqa: E501
         :rtype: str
@@ -343,7 +344,7 @@ class FormField(object):
     def status_text(self, status_text):
         """Sets the status_text of this FormField.
 
-        Gets or sets returns or sets the text that's displayed in the status bar when a form field has the focus.  # noqa: E501
+        Gets or sets text, displayed in the status bar when a form field has the focus.  # noqa: E501
 
         :param status_text: The status_text of this FormField.  # noqa: E501
         :type: str
@@ -357,21 +358,25 @@ class FormField(object):
 
         for attr, _ in six.iteritems(self.swagger_types):
             value = getattr(self, attr)
+            if value is None:
+                continue
             if isinstance(value, list):
-                result[attr] = list(map(
+                result[self.attribute_map[attr]] = list(map(
                     lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                     value
                 ))
             elif hasattr(value, "to_dict"):
-                result[attr] = value.to_dict()
+                result[self.attribute_map[attr]] = value.to_dict()
             elif isinstance(value, dict):
-                result[attr] = dict(map(
+                result[self.attribute_map[attr]] = dict(map(
                     lambda item: (item[0], item[1].to_dict())
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
-                result[attr] = value
+                result[self.attribute_map[attr]] = value
 
         return result
 
@@ -394,6 +399,8 @@ class FormField(object):
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
                 result[self.attribute_map[attr]] = value
 
