@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="form_field_checkbox.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -26,6 +26,7 @@
 import pprint
 import re  # noqa: F401
 
+import datetime
 import six
 import json
 
@@ -127,7 +128,7 @@ class FormFieldCheckbox(object):
     def link(self):
         """Gets the link of this FormFieldCheckbox.  # noqa: E501
 
-        Gets or sets link to the document.  # noqa: E501
+        Gets or sets the link to the document.  # noqa: E501
 
         :return: The link of this FormFieldCheckbox.  # noqa: E501
         :rtype: WordsApiLink
@@ -138,7 +139,7 @@ class FormFieldCheckbox(object):
     def link(self, link):
         """Sets the link of this FormFieldCheckbox.
 
-        Gets or sets link to the document.  # noqa: E501
+        Gets or sets the link to the document.  # noqa: E501
 
         :param link: The link of this FormFieldCheckbox.  # noqa: E501
         :type: WordsApiLink
@@ -149,7 +150,7 @@ class FormFieldCheckbox(object):
     def node_id(self):
         """Gets the node_id of this FormFieldCheckbox.  # noqa: E501
 
-        Gets or sets node id.  # noqa: E501
+        Gets or sets the node id.  # noqa: E501
 
         :return: The node_id of this FormFieldCheckbox.  # noqa: E501
         :rtype: str
@@ -160,7 +161,7 @@ class FormFieldCheckbox(object):
     def node_id(self, node_id):
         """Sets the node_id of this FormFieldCheckbox.
 
-        Gets or sets node id.  # noqa: E501
+        Gets or sets the node id.  # noqa: E501
 
         :param node_id: The node_id of this FormFieldCheckbox.  # noqa: E501
         :type: str
@@ -171,7 +172,7 @@ class FormFieldCheckbox(object):
     def calculate_on_exit(self):
         """Gets the calculate_on_exit of this FormFieldCheckbox.  # noqa: E501
 
-        Gets or sets true if references to the specified form field are automatically updated whenever the field is exited.  # noqa: E501
+        Gets or sets a value indicating whether references to the specified form field are automatically updated whenever the field is exited.  # noqa: E501
 
         :return: The calculate_on_exit of this FormFieldCheckbox.  # noqa: E501
         :rtype: bool
@@ -182,7 +183,7 @@ class FormFieldCheckbox(object):
     def calculate_on_exit(self, calculate_on_exit):
         """Sets the calculate_on_exit of this FormFieldCheckbox.
 
-        Gets or sets true if references to the specified form field are automatically updated whenever the field is exited.  # noqa: E501
+        Gets or sets a value indicating whether references to the specified form field are automatically updated whenever the field is exited.  # noqa: E501
 
         :param calculate_on_exit: The calculate_on_exit of this FormFieldCheckbox.  # noqa: E501
         :type: bool
@@ -193,7 +194,7 @@ class FormFieldCheckbox(object):
     def enabled(self):
         """Gets the enabled of this FormFieldCheckbox.  # noqa: E501
 
-        Gets or sets true if a form field is enabled.  # noqa: E501
+        Gets or sets a value indicating whether a form field is enabled.  # noqa: E501
 
         :return: The enabled of this FormFieldCheckbox.  # noqa: E501
         :rtype: bool
@@ -204,7 +205,7 @@ class FormFieldCheckbox(object):
     def enabled(self, enabled):
         """Sets the enabled of this FormFieldCheckbox.
 
-        Gets or sets true if a form field is enabled.  # noqa: E501
+        Gets or sets a value indicating whether a form field is enabled.  # noqa: E501
 
         :param enabled: The enabled of this FormFieldCheckbox.  # noqa: E501
         :type: bool
@@ -215,7 +216,7 @@ class FormFieldCheckbox(object):
     def entry_macro(self):
         """Gets the entry_macro of this FormFieldCheckbox.  # noqa: E501
 
-        Gets or sets returns or sets an entry macro name for the form field.  # noqa: E501
+        Gets or sets the entry macro name for the form field.  # noqa: E501
 
         :return: The entry_macro of this FormFieldCheckbox.  # noqa: E501
         :rtype: str
@@ -226,7 +227,7 @@ class FormFieldCheckbox(object):
     def entry_macro(self, entry_macro):
         """Sets the entry_macro of this FormFieldCheckbox.
 
-        Gets or sets returns or sets an entry macro name for the form field.  # noqa: E501
+        Gets or sets the entry macro name for the form field.  # noqa: E501
 
         :param entry_macro: The entry_macro of this FormFieldCheckbox.  # noqa: E501
         :type: str
@@ -237,7 +238,7 @@ class FormFieldCheckbox(object):
     def exit_macro(self):
         """Gets the exit_macro of this FormFieldCheckbox.  # noqa: E501
 
-        Gets or sets returns or sets an exit macro name for the form field.  # noqa: E501
+        Gets or sets the exit macro name for the form field.  # noqa: E501
 
         :return: The exit_macro of this FormFieldCheckbox.  # noqa: E501
         :rtype: str
@@ -248,7 +249,7 @@ class FormFieldCheckbox(object):
     def exit_macro(self, exit_macro):
         """Sets the exit_macro of this FormFieldCheckbox.
 
-        Gets or sets returns or sets an exit macro name for the form field.  # noqa: E501
+        Gets or sets the exit macro name for the form field.  # noqa: E501
 
         :param exit_macro: The exit_macro of this FormFieldCheckbox.  # noqa: E501
         :type: str
@@ -259,7 +260,7 @@ class FormFieldCheckbox(object):
     def help_text(self):
         """Gets the help_text of this FormFieldCheckbox.  # noqa: E501
 
-        Gets or sets returns or sets the text that's displayed in a message box when the form field has the focus and the user presses F1.  # noqa: E501
+        Gets or sets text, displayed in a message box when the form field has the focus and the user presses F1.  # noqa: E501
 
         :return: The help_text of this FormFieldCheckbox.  # noqa: E501
         :rtype: str
@@ -270,7 +271,7 @@ class FormFieldCheckbox(object):
     def help_text(self, help_text):
         """Sets the help_text of this FormFieldCheckbox.
 
-        Gets or sets returns or sets the text that's displayed in a message box when the form field has the focus and the user presses F1.  # noqa: E501
+        Gets or sets text, displayed in a message box when the form field has the focus and the user presses F1.  # noqa: E501
 
         :param help_text: The help_text of this FormFieldCheckbox.  # noqa: E501
         :type: str
@@ -303,7 +304,7 @@ class FormFieldCheckbox(object):
     def own_help(self):
         """Gets the own_help of this FormFieldCheckbox.  # noqa: E501
 
-        Gets or sets specifies the source of the text that's displayed in a message box when a form field has the focus and the user presses F1.  # noqa: E501
+        Gets or sets a value indicating whether the source of the text that's displayed in a message box when a form field has the focus and the user presses F1.  # noqa: E501
 
         :return: The own_help of this FormFieldCheckbox.  # noqa: E501
         :rtype: bool
@@ -314,7 +315,7 @@ class FormFieldCheckbox(object):
     def own_help(self, own_help):
         """Sets the own_help of this FormFieldCheckbox.
 
-        Gets or sets specifies the source of the text that's displayed in a message box when a form field has the focus and the user presses F1.  # noqa: E501
+        Gets or sets a value indicating whether the source of the text that's displayed in a message box when a form field has the focus and the user presses F1.  # noqa: E501
 
         :param own_help: The own_help of this FormFieldCheckbox.  # noqa: E501
         :type: bool
@@ -325,7 +326,7 @@ class FormFieldCheckbox(object):
     def own_status(self):
         """Gets the own_status of this FormFieldCheckbox.  # noqa: E501
 
-        Gets or sets specifies the source of the text that's displayed in the status bar when a form field has the focus.  # noqa: E501
+        Gets or sets a value indicating whether the source of the text that's displayed in the status bar when a form field has the focus.  # noqa: E501
 
         :return: The own_status of this FormFieldCheckbox.  # noqa: E501
         :rtype: bool
@@ -336,7 +337,7 @@ class FormFieldCheckbox(object):
     def own_status(self, own_status):
         """Sets the own_status of this FormFieldCheckbox.
 
-        Gets or sets specifies the source of the text that's displayed in the status bar when a form field has the focus.  # noqa: E501
+        Gets or sets a value indicating whether the source of the text that's displayed in the status bar when a form field has the focus.  # noqa: E501
 
         :param own_status: The own_status of this FormFieldCheckbox.  # noqa: E501
         :type: bool
@@ -347,7 +348,7 @@ class FormFieldCheckbox(object):
     def status_text(self):
         """Gets the status_text of this FormFieldCheckbox.  # noqa: E501
 
-        Gets or sets returns or sets the text that's displayed in the status bar when a form field has the focus.  # noqa: E501
+        Gets or sets text, displayed in the status bar when a form field has the focus.  # noqa: E501
 
         :return: The status_text of this FormFieldCheckbox.  # noqa: E501
         :rtype: str
@@ -358,7 +359,7 @@ class FormFieldCheckbox(object):
     def status_text(self, status_text):
         """Sets the status_text of this FormFieldCheckbox.
 
-        Gets or sets returns or sets the text that's displayed in the status bar when a form field has the focus.  # noqa: E501
+        Gets or sets text, displayed in the status bar when a form field has the focus.  # noqa: E501
 
         :param status_text: The status_text of this FormFieldCheckbox.  # noqa: E501
         :type: str
@@ -413,7 +414,7 @@ class FormFieldCheckbox(object):
     def is_check_box_exact_size(self):
         """Gets the is_check_box_exact_size of this FormFieldCheckbox.  # noqa: E501
 
-        Gets or sets the boolean value that indicates whether the size of the textbox is automatic or specified explicitly.  # noqa: E501
+        Gets or sets a value indicating whether the size of the textbox is automatic or specified explicitly.  # noqa: E501
 
         :return: The is_check_box_exact_size of this FormFieldCheckbox.  # noqa: E501
         :rtype: bool
@@ -424,7 +425,7 @@ class FormFieldCheckbox(object):
     def is_check_box_exact_size(self, is_check_box_exact_size):
         """Sets the is_check_box_exact_size of this FormFieldCheckbox.
 
-        Gets or sets the boolean value that indicates whether the size of the textbox is automatic or specified explicitly.  # noqa: E501
+        Gets or sets a value indicating whether the size of the textbox is automatic or specified explicitly.  # noqa: E501
 
         :param is_check_box_exact_size: The is_check_box_exact_size of this FormFieldCheckbox.  # noqa: E501
         :type: bool
@@ -438,21 +439,25 @@ class FormFieldCheckbox(object):
 
         for attr, _ in six.iteritems(self.swagger_types):
             value = getattr(self, attr)
+            if value is None:
+                continue
             if isinstance(value, list):
-                result[attr] = list(map(
+                result[self.attribute_map[attr]] = list(map(
                     lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                     value
                 ))
             elif hasattr(value, "to_dict"):
-                result[attr] = value.to_dict()
+                result[self.attribute_map[attr]] = value.to_dict()
             elif isinstance(value, dict):
-                result[attr] = dict(map(
+                result[self.attribute_map[attr]] = dict(map(
                     lambda item: (item[0], item[1].to_dict())
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
-                result[attr] = value
+                result[self.attribute_map[attr]] = value
 
         return result
 
@@ -475,6 +480,8 @@ class FormFieldCheckbox(object):
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
                 result[self.attribute_map[attr]] = value
 
