@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="form_field_text_input.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -26,6 +26,7 @@
 import pprint
 import re  # noqa: F401
 
+import datetime
 import six
 import json
 
@@ -132,7 +133,7 @@ class FormFieldTextInput(object):
     def link(self):
         """Gets the link of this FormFieldTextInput.  # noqa: E501
 
-        Gets or sets link to the document.  # noqa: E501
+        Gets or sets the link to the document.  # noqa: E501
 
         :return: The link of this FormFieldTextInput.  # noqa: E501
         :rtype: WordsApiLink
@@ -143,7 +144,7 @@ class FormFieldTextInput(object):
     def link(self, link):
         """Sets the link of this FormFieldTextInput.
 
-        Gets or sets link to the document.  # noqa: E501
+        Gets or sets the link to the document.  # noqa: E501
 
         :param link: The link of this FormFieldTextInput.  # noqa: E501
         :type: WordsApiLink
@@ -154,7 +155,7 @@ class FormFieldTextInput(object):
     def node_id(self):
         """Gets the node_id of this FormFieldTextInput.  # noqa: E501
 
-        Gets or sets node id.  # noqa: E501
+        Gets or sets the node id.  # noqa: E501
 
         :return: The node_id of this FormFieldTextInput.  # noqa: E501
         :rtype: str
@@ -165,7 +166,7 @@ class FormFieldTextInput(object):
     def node_id(self, node_id):
         """Sets the node_id of this FormFieldTextInput.
 
-        Gets or sets node id.  # noqa: E501
+        Gets or sets the node id.  # noqa: E501
 
         :param node_id: The node_id of this FormFieldTextInput.  # noqa: E501
         :type: str
@@ -176,7 +177,7 @@ class FormFieldTextInput(object):
     def calculate_on_exit(self):
         """Gets the calculate_on_exit of this FormFieldTextInput.  # noqa: E501
 
-        Gets or sets true if references to the specified form field are automatically updated whenever the field is exited.  # noqa: E501
+        Gets or sets a value indicating whether references to the specified form field are automatically updated whenever the field is exited.  # noqa: E501
 
         :return: The calculate_on_exit of this FormFieldTextInput.  # noqa: E501
         :rtype: bool
@@ -187,7 +188,7 @@ class FormFieldTextInput(object):
     def calculate_on_exit(self, calculate_on_exit):
         """Sets the calculate_on_exit of this FormFieldTextInput.
 
-        Gets or sets true if references to the specified form field are automatically updated whenever the field is exited.  # noqa: E501
+        Gets or sets a value indicating whether references to the specified form field are automatically updated whenever the field is exited.  # noqa: E501
 
         :param calculate_on_exit: The calculate_on_exit of this FormFieldTextInput.  # noqa: E501
         :type: bool
@@ -198,7 +199,7 @@ class FormFieldTextInput(object):
     def enabled(self):
         """Gets the enabled of this FormFieldTextInput.  # noqa: E501
 
-        Gets or sets true if a form field is enabled.  # noqa: E501
+        Gets or sets a value indicating whether a form field is enabled.  # noqa: E501
 
         :return: The enabled of this FormFieldTextInput.  # noqa: E501
         :rtype: bool
@@ -209,7 +210,7 @@ class FormFieldTextInput(object):
     def enabled(self, enabled):
         """Sets the enabled of this FormFieldTextInput.
 
-        Gets or sets true if a form field is enabled.  # noqa: E501
+        Gets or sets a value indicating whether a form field is enabled.  # noqa: E501
 
         :param enabled: The enabled of this FormFieldTextInput.  # noqa: E501
         :type: bool
@@ -220,7 +221,7 @@ class FormFieldTextInput(object):
     def entry_macro(self):
         """Gets the entry_macro of this FormFieldTextInput.  # noqa: E501
 
-        Gets or sets returns or sets an entry macro name for the form field.  # noqa: E501
+        Gets or sets the entry macro name for the form field.  # noqa: E501
 
         :return: The entry_macro of this FormFieldTextInput.  # noqa: E501
         :rtype: str
@@ -231,7 +232,7 @@ class FormFieldTextInput(object):
     def entry_macro(self, entry_macro):
         """Sets the entry_macro of this FormFieldTextInput.
 
-        Gets or sets returns or sets an entry macro name for the form field.  # noqa: E501
+        Gets or sets the entry macro name for the form field.  # noqa: E501
 
         :param entry_macro: The entry_macro of this FormFieldTextInput.  # noqa: E501
         :type: str
@@ -242,7 +243,7 @@ class FormFieldTextInput(object):
     def exit_macro(self):
         """Gets the exit_macro of this FormFieldTextInput.  # noqa: E501
 
-        Gets or sets returns or sets an exit macro name for the form field.  # noqa: E501
+        Gets or sets the exit macro name for the form field.  # noqa: E501
 
         :return: The exit_macro of this FormFieldTextInput.  # noqa: E501
         :rtype: str
@@ -253,7 +254,7 @@ class FormFieldTextInput(object):
     def exit_macro(self, exit_macro):
         """Sets the exit_macro of this FormFieldTextInput.
 
-        Gets or sets returns or sets an exit macro name for the form field.  # noqa: E501
+        Gets or sets the exit macro name for the form field.  # noqa: E501
 
         :param exit_macro: The exit_macro of this FormFieldTextInput.  # noqa: E501
         :type: str
@@ -264,7 +265,7 @@ class FormFieldTextInput(object):
     def help_text(self):
         """Gets the help_text of this FormFieldTextInput.  # noqa: E501
 
-        Gets or sets returns or sets the text that's displayed in a message box when the form field has the focus and the user presses F1.  # noqa: E501
+        Gets or sets text, displayed in a message box when the form field has the focus and the user presses F1.  # noqa: E501
 
         :return: The help_text of this FormFieldTextInput.  # noqa: E501
         :rtype: str
@@ -275,7 +276,7 @@ class FormFieldTextInput(object):
     def help_text(self, help_text):
         """Sets the help_text of this FormFieldTextInput.
 
-        Gets or sets returns or sets the text that's displayed in a message box when the form field has the focus and the user presses F1.  # noqa: E501
+        Gets or sets text, displayed in a message box when the form field has the focus and the user presses F1.  # noqa: E501
 
         :param help_text: The help_text of this FormFieldTextInput.  # noqa: E501
         :type: str
@@ -308,7 +309,7 @@ class FormFieldTextInput(object):
     def own_help(self):
         """Gets the own_help of this FormFieldTextInput.  # noqa: E501
 
-        Gets or sets specifies the source of the text that's displayed in a message box when a form field has the focus and the user presses F1.  # noqa: E501
+        Gets or sets a value indicating whether the source of the text that's displayed in a message box when a form field has the focus and the user presses F1.  # noqa: E501
 
         :return: The own_help of this FormFieldTextInput.  # noqa: E501
         :rtype: bool
@@ -319,7 +320,7 @@ class FormFieldTextInput(object):
     def own_help(self, own_help):
         """Sets the own_help of this FormFieldTextInput.
 
-        Gets or sets specifies the source of the text that's displayed in a message box when a form field has the focus and the user presses F1.  # noqa: E501
+        Gets or sets a value indicating whether the source of the text that's displayed in a message box when a form field has the focus and the user presses F1.  # noqa: E501
 
         :param own_help: The own_help of this FormFieldTextInput.  # noqa: E501
         :type: bool
@@ -330,7 +331,7 @@ class FormFieldTextInput(object):
     def own_status(self):
         """Gets the own_status of this FormFieldTextInput.  # noqa: E501
 
-        Gets or sets specifies the source of the text that's displayed in the status bar when a form field has the focus.  # noqa: E501
+        Gets or sets a value indicating whether the source of the text that's displayed in the status bar when a form field has the focus.  # noqa: E501
 
         :return: The own_status of this FormFieldTextInput.  # noqa: E501
         :rtype: bool
@@ -341,7 +342,7 @@ class FormFieldTextInput(object):
     def own_status(self, own_status):
         """Sets the own_status of this FormFieldTextInput.
 
-        Gets or sets specifies the source of the text that's displayed in the status bar when a form field has the focus.  # noqa: E501
+        Gets or sets a value indicating whether the source of the text that's displayed in the status bar when a form field has the focus.  # noqa: E501
 
         :param own_status: The own_status of this FormFieldTextInput.  # noqa: E501
         :type: bool
@@ -352,7 +353,7 @@ class FormFieldTextInput(object):
     def status_text(self):
         """Gets the status_text of this FormFieldTextInput.  # noqa: E501
 
-        Gets or sets returns or sets the text that's displayed in the status bar when a form field has the focus.  # noqa: E501
+        Gets or sets text, displayed in the status bar when a form field has the focus.  # noqa: E501
 
         :return: The status_text of this FormFieldTextInput.  # noqa: E501
         :rtype: str
@@ -363,7 +364,7 @@ class FormFieldTextInput(object):
     def status_text(self, status_text):
         """Sets the status_text of this FormFieldTextInput.
 
-        Gets or sets returns or sets the text that's displayed in the status bar when a form field has the focus.  # noqa: E501
+        Gets or sets text, displayed in the status bar when a form field has the focus.  # noqa: E501
 
         :param status_text: The status_text of this FormFieldTextInput.  # noqa: E501
         :type: str
@@ -374,7 +375,7 @@ class FormFieldTextInput(object):
     def max_length(self):
         """Gets the max_length of this FormFieldTextInput.  # noqa: E501
 
-        Gets or sets maximum length for the text field. Zero when the length is not limited.  # noqa: E501
+        Gets or sets the maximum length for the text field. Zero when the length is not limited.  # noqa: E501
 
         :return: The max_length of this FormFieldTextInput.  # noqa: E501
         :rtype: int
@@ -385,7 +386,7 @@ class FormFieldTextInput(object):
     def max_length(self, max_length):
         """Sets the max_length of this FormFieldTextInput.
 
-        Gets or sets maximum length for the text field. Zero when the length is not limited.  # noqa: E501
+        Gets or sets the maximum length for the text field. Zero when the length is not limited.  # noqa: E501
 
         :param max_length: The max_length of this FormFieldTextInput.  # noqa: E501
         :type: int
@@ -396,7 +397,7 @@ class FormFieldTextInput(object):
     def text_input_default(self):
         """Gets the text_input_default of this FormFieldTextInput.  # noqa: E501
 
-        Gets or sets the default string or a calculation expression of a text form field.  # noqa: E501
+        Gets or sets the default string or a calculation expression of the text form field.  # noqa: E501
 
         :return: The text_input_default of this FormFieldTextInput.  # noqa: E501
         :rtype: str
@@ -407,7 +408,7 @@ class FormFieldTextInput(object):
     def text_input_default(self, text_input_default):
         """Sets the text_input_default of this FormFieldTextInput.
 
-        Gets or sets the default string or a calculation expression of a text form field.  # noqa: E501
+        Gets or sets the default string or a calculation expression of the text form field.  # noqa: E501
 
         :param text_input_default: The text_input_default of this FormFieldTextInput.  # noqa: E501
         :type: str
@@ -418,7 +419,7 @@ class FormFieldTextInput(object):
     def text_input_format(self):
         """Gets the text_input_format of this FormFieldTextInput.  # noqa: E501
 
-        Gets or sets returns or sets the text formatting for a text form field.  # noqa: E501
+        Gets or sets text formatting for the text form field.  # noqa: E501
 
         :return: The text_input_format of this FormFieldTextInput.  # noqa: E501
         :rtype: str
@@ -429,7 +430,7 @@ class FormFieldTextInput(object):
     def text_input_format(self, text_input_format):
         """Sets the text_input_format of this FormFieldTextInput.
 
-        Gets or sets returns or sets the text formatting for a text form field.  # noqa: E501
+        Gets or sets text formatting for the text form field.  # noqa: E501
 
         :param text_input_format: The text_input_format of this FormFieldTextInput.  # noqa: E501
         :type: str
@@ -440,7 +441,7 @@ class FormFieldTextInput(object):
     def text_input_type(self):
         """Gets the text_input_type of this FormFieldTextInput.  # noqa: E501
 
-        Gets or sets the type of a text form field.  # noqa: E501
+        Gets or sets the type of the text form field.  # noqa: E501
 
         :return: The text_input_type of this FormFieldTextInput.  # noqa: E501
         :rtype: str
@@ -451,7 +452,7 @@ class FormFieldTextInput(object):
     def text_input_type(self, text_input_type):
         """Sets the text_input_type of this FormFieldTextInput.
 
-        Gets or sets the type of a text form field.  # noqa: E501
+        Gets or sets the type of the text form field.  # noqa: E501
 
         :param text_input_type: The text_input_type of this FormFieldTextInput.  # noqa: E501
         :type: str
@@ -473,21 +474,25 @@ class FormFieldTextInput(object):
 
         for attr, _ in six.iteritems(self.swagger_types):
             value = getattr(self, attr)
+            if value is None:
+                continue
             if isinstance(value, list):
-                result[attr] = list(map(
+                result[self.attribute_map[attr]] = list(map(
                     lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                     value
                 ))
             elif hasattr(value, "to_dict"):
-                result[attr] = value.to_dict()
+                result[self.attribute_map[attr]] = value.to_dict()
             elif isinstance(value, dict):
-                result[attr] = dict(map(
+                result[self.attribute_map[attr]] = dict(map(
                     lambda item: (item[0], item[1].to_dict())
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
-                result[attr] = value
+                result[self.attribute_map[attr]] = value
 
         return result
 
@@ -510,6 +515,8 @@ class FormFieldTextInput(object):
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
                 result[self.attribute_map[attr]] = value
 
