@@ -29,6 +29,8 @@ from asposewordscloud.models.requests.delete_borders_request import DeleteBorder
 from asposewordscloud.models.requests.delete_borders_online_request import DeleteBordersOnlineRequest
 from asposewordscloud.models.requests.delete_comment_request import DeleteCommentRequest
 from asposewordscloud.models.requests.delete_comment_online_request import DeleteCommentOnlineRequest
+from asposewordscloud.models.requests.delete_comments_request import DeleteCommentsRequest
+from asposewordscloud.models.requests.delete_comments_online_request import DeleteCommentsOnlineRequest
 from asposewordscloud.models.requests.delete_document_property_request import DeleteDocumentPropertyRequest
 from asposewordscloud.models.requests.delete_document_property_online_request import DeleteDocumentPropertyOnlineRequest
 from asposewordscloud.models.requests.delete_drawing_object_request import DeleteDrawingObjectRequest
