@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="copy_style_request.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -23,14 +23,18 @@
 #  SOFTWARE.
 # </summary>
 # -----------------------------------------------------------------------------------
+import json
 
 from six.moves.urllib.parse import quote
+from asposewordscloud import *
+from asposewordscloud.models.requests import *
+from asposewordscloud.models.responses import *
 
-class CopyStyleRequest(object):
+class CopyStyleRequest(BaseRequestObject):
     """
     Request model for copy_style operation.
     Initializes a new instance.
-    :param name The document name.
+    :param name The filename of the input document.
     :param style_copy Style to copy.
     :param folder Original document folder.
     :param storage Original document storage.
@@ -121,4 +125,7 @@ class CopyStyleRequest(object):
         }
 
     def get_response_type(self):
-        return 'StyleResponse'  # noqa: E501
\ No newline at end of file
+        return 'StyleResponse'  # noqa: E501
+
+    def deserialize_response(self, api_client, response):
+        return self.deserialize(response, StyleResponse, api_client)
