@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="get_header_footer_request.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -23,20 +23,24 @@
 #  SOFTWARE.
 # </summary>
 # -----------------------------------------------------------------------------------
+import json
 
 from six.moves.urllib.parse import quote
+from asposewordscloud import *
+from asposewordscloud.models.requests import *
+from asposewordscloud.models.responses import *
 
-class GetHeaderFooterRequest(object):
+class GetHeaderFooterRequest(BaseRequestObject):
     """
     Request model for get_header_footer operation.
     Initializes a new instance.
-    :param name The document name.
-    :param header_footer_index Header/footer index.
+    :param name The filename of the input document.
+    :param header_footer_index The index of the HeaderFooter object.
     :param folder Original document folder.
     :param storage Original document storage.
     :param load_encoding Encoding that will be used to load an HTML (or TXT) document if the encoding is not specified in HTML.
     :param password Password for opening an encrypted document.
-    :param filter_by_type List of types of headers and footers.
+    :param filter_by_type The list of HeaderFooter types.
     """
 
     def __init__(self, name, header_footer_index, folder=None, storage=None, load_encoding=None, password=None, filter_by_type=None):
@@ -111,4 +115,7 @@ class GetHeaderFooterRequest(object):
         }
 
     def get_response_type(self):
-        return 'HeaderFooterResponse'  # noqa: E501
\ No newline at end of file
+        return 'HeaderFooterResponse'  # noqa: E501
+
+    def deserialize_response(self, api_client, response):
+        return self.deserialize(response, HeaderFooterResponse, api_client)
