@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="get_range_text_request.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -23,15 +23,19 @@
 #  SOFTWARE.
 # </summary>
 # -----------------------------------------------------------------------------------
+import json
 
 from six.moves.urllib.parse import quote
+from asposewordscloud import *
+from asposewordscloud.models.requests import *
+from asposewordscloud.models.responses import *
 
-class GetRangeTextRequest(object):
+class GetRangeTextRequest(BaseRequestObject):
     """
     Request model for get_range_text operation.
     Initializes a new instance.
-    :param name The document.
-    :param range_start_identifier The range start identifier. Identifier is the value of the "nodeId" field, which every document node has, extended with the prefix "id". It looks like "id0.0.7". Also values like "image5" and "table3" can be used as an identifier for images and tables, where the number is an index of the image/table.
+    :param name The filename of the input document.
+    :param range_start_identifier The range start identifier.
     :param range_end_identifier The range end identifier.
     :param folder Original document folder.
     :param storage Original document storage.
@@ -113,4 +117,7 @@ class GetRangeTextRequest(object):
         }
 
     def get_response_type(self):
-        return 'RangeTextResponse'  # noqa: E501
\ No newline at end of file
+        return 'RangeTextResponse'  # noqa: E501
+
+    def deserialize_response(self, api_client, response):
+        return self.deserialize(response, RangeTextResponse, api_client)
