@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="reset_cache_request.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -23,10 +23,14 @@
 #  SOFTWARE.
 # </summary>
 # -----------------------------------------------------------------------------------
+import json
 
 from six.moves.urllib.parse import quote
+from asposewordscloud import *
+from asposewordscloud.models.requests import *
+from asposewordscloud.models.responses import *
 
-class ResetCacheRequest(object):
+class ResetCacheRequest(BaseRequestObject):
     """
     Request model for reset_cache operation.
     Initializes a new instance.
@@ -69,8 +73,11 @@ class ResetCacheRequest(object):
             "form_params": form_params,
             "body": body_params,
             "collection_formats": collection_formats,
-            "response_type": None  # noqa: E501
+            "response_type": 'None'  # noqa: E501
         }
 
     def get_response_type(self):
-        return None  # noqa: E501
\ No newline at end of file
+        return 'None'  # noqa: E501
+
+    def deserialize_response(self, api_client, response):
+        return None
