@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="save_result.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -26,6 +26,7 @@
 import pprint
 import re  # noqa: F401
 
+import datetime
 import six
 import json
 
@@ -72,7 +73,7 @@ class SaveResult(object):
     def additional_items(self):
         """Gets the additional_items of this SaveResult.  # noqa: E501
 
-        Gets or sets links to additional items (css, images etc).  # noqa: E501
+        Gets or sets the list of links to additional items (css, images etc).  # noqa: E501
 
         :return: The additional_items of this SaveResult.  # noqa: E501
         :rtype: list[FileLink]
@@ -83,7 +84,7 @@ class SaveResult(object):
     def additional_items(self, additional_items):
         """Sets the additional_items of this SaveResult.
 
-        Gets or sets links to additional items (css, images etc).  # noqa: E501
+        Gets or sets the list of links to additional items (css, images etc).  # noqa: E501
 
         :param additional_items: The additional_items of this SaveResult.  # noqa: E501
         :type: list[FileLink]
@@ -94,7 +95,7 @@ class SaveResult(object):
     def dest_document(self):
         """Gets the dest_document of this SaveResult.  # noqa: E501
 
-        Gets or sets link to destination document.  # noqa: E501
+        Gets or sets the link to destination document.  # noqa: E501
 
         :return: The dest_document of this SaveResult.  # noqa: E501
         :rtype: FileLink
@@ -105,7 +106,7 @@ class SaveResult(object):
     def dest_document(self, dest_document):
         """Sets the dest_document of this SaveResult.
 
-        Gets or sets link to destination document.  # noqa: E501
+        Gets or sets the link to destination document.  # noqa: E501
 
         :param dest_document: The dest_document of this SaveResult.  # noqa: E501
         :type: FileLink
@@ -116,7 +117,7 @@ class SaveResult(object):
     def source_document(self):
         """Gets the source_document of this SaveResult.  # noqa: E501
 
-        Gets or sets link to source document.  # noqa: E501
+        Gets or sets the link to source document.  # noqa: E501
 
         :return: The source_document of this SaveResult.  # noqa: E501
         :rtype: FileLink
@@ -127,7 +128,7 @@ class SaveResult(object):
     def source_document(self, source_document):
         """Sets the source_document of this SaveResult.
 
-        Gets or sets link to source document.  # noqa: E501
+        Gets or sets the link to source document.  # noqa: E501
 
         :param source_document: The source_document of this SaveResult.  # noqa: E501
         :type: FileLink
@@ -141,21 +142,25 @@ class SaveResult(object):
 
         for attr, _ in six.iteritems(self.swagger_types):
             value = getattr(self, attr)
+            if value is None:
+                continue
             if isinstance(value, list):
-                result[attr] = list(map(
+                result[self.attribute_map[attr]] = list(map(
                     lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                     value
                 ))
             elif hasattr(value, "to_dict"):
-                result[attr] = value.to_dict()
+                result[self.attribute_map[attr]] = value.to_dict()
             elif isinstance(value, dict):
-                result[attr] = dict(map(
+                result[self.attribute_map[attr]] = dict(map(
                     lambda item: (item[0], item[1].to_dict())
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
-                result[attr] = value
+                result[self.attribute_map[attr]] = value
 
         return result
 
@@ -178,6 +183,8 @@ class SaveResult(object):
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
                 result[self.attribute_map[attr]] = value
 
