@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="table_insert.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -26,12 +26,13 @@
 import pprint
 import re  # noqa: F401
 
+import datetime
 import six
 import json
 
 
 class TableInsert(object):
-    """Table element.
+    """DTO container with a table element.
     """
 
     """
@@ -72,7 +73,7 @@ class TableInsert(object):
     def columns_count(self):
         """Gets the columns_count of this TableInsert.  # noqa: E501
 
-        Gets or sets count of columns. Default is 2.  # noqa: E501
+        Gets or sets the number of columns. The default value is 2.  # noqa: E501
 
         :return: The columns_count of this TableInsert.  # noqa: E501
         :rtype: int
@@ -83,7 +84,7 @@ class TableInsert(object):
     def columns_count(self, columns_count):
         """Sets the columns_count of this TableInsert.
 
-        Gets or sets count of columns. Default is 2.  # noqa: E501
+        Gets or sets the number of columns. The default value is 2.  # noqa: E501
 
         :param columns_count: The columns_count of this TableInsert.  # noqa: E501
         :type: int
@@ -94,7 +95,7 @@ class TableInsert(object):
     def position(self):
         """Gets the position of this TableInsert.  # noqa: E501
 
-        Gets or sets table will be inserted before specified position.  # noqa: E501
+        Gets or sets the position to insert the table. The table will be inserted before the specified position.  # noqa: E501
 
         :return: The position of this TableInsert.  # noqa: E501
         :rtype: DocumentPosition
@@ -105,7 +106,7 @@ class TableInsert(object):
     def position(self, position):
         """Sets the position of this TableInsert.
 
-        Gets or sets table will be inserted before specified position.  # noqa: E501
+        Gets or sets the position to insert the table. The table will be inserted before the specified position.  # noqa: E501
 
         :param position: The position of this TableInsert.  # noqa: E501
         :type: DocumentPosition
@@ -116,7 +117,7 @@ class TableInsert(object):
     def rows_count(self):
         """Gets the rows_count of this TableInsert.  # noqa: E501
 
-        Gets or sets count of rows. Default is 2.  # noqa: E501
+        Gets or sets the number of rows. The default value is 2.  # noqa: E501
 
         :return: The rows_count of this TableInsert.  # noqa: E501
         :rtype: int
@@ -127,7 +128,7 @@ class TableInsert(object):
     def rows_count(self, rows_count):
         """Sets the rows_count of this TableInsert.
 
-        Gets or sets count of rows. Default is 2.  # noqa: E501
+        Gets or sets the number of rows. The default value is 2.  # noqa: E501
 
         :param rows_count: The rows_count of this TableInsert.  # noqa: E501
         :type: int
@@ -141,21 +142,25 @@ class TableInsert(object):
 
         for attr, _ in six.iteritems(self.swagger_types):
             value = getattr(self, attr)
+            if value is None:
+                continue
             if isinstance(value, list):
-                result[attr] = list(map(
+                result[self.attribute_map[attr]] = list(map(
                     lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                     value
                 ))
             elif hasattr(value, "to_dict"):
-                result[attr] = value.to_dict()
+                result[self.attribute_map[attr]] = value.to_dict()
             elif isinstance(value, dict):
-                result[attr] = dict(map(
+                result[self.attribute_map[attr]] = dict(map(
                     lambda item: (item[0], item[1].to_dict())
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
-                result[attr] = value
+                result[self.attribute_map[attr]] = value
 
         return result
 
@@ -178,6 +183,8 @@ class TableInsert(object):
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
                 result[self.attribute_map[attr]] = value
 
