@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="table_row.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -26,12 +26,13 @@
 import pprint
 import re  # noqa: F401
 
+import datetime
 import six
 import json
 
 
 class TableRow(object):
-    """Table row element.
+    """DTO container with a table row element.
     """
 
     """
@@ -77,7 +78,7 @@ class TableRow(object):
     def link(self):
         """Gets the link of this TableRow.  # noqa: E501
 
-        Gets or sets link to the document.  # noqa: E501
+        Gets or sets the link to the document.  # noqa: E501
 
         :return: The link of this TableRow.  # noqa: E501
         :rtype: WordsApiLink
@@ -88,7 +89,7 @@ class TableRow(object):
     def link(self, link):
         """Sets the link of this TableRow.
 
-        Gets or sets link to the document.  # noqa: E501
+        Gets or sets the link to the document.  # noqa: E501
 
         :param link: The link of this TableRow.  # noqa: E501
         :type: WordsApiLink
@@ -99,7 +100,7 @@ class TableRow(object):
     def node_id(self):
         """Gets the node_id of this TableRow.  # noqa: E501
 
-        Gets or sets node id.  # noqa: E501
+        Gets or sets the node id.  # noqa: E501
 
         :return: The node_id of this TableRow.  # noqa: E501
         :rtype: str
@@ -110,7 +111,7 @@ class TableRow(object):
     def node_id(self, node_id):
         """Sets the node_id of this TableRow.
 
-        Gets or sets node id.  # noqa: E501
+        Gets or sets the node id.  # noqa: E501
 
         :param node_id: The node_id of this TableRow.  # noqa: E501
         :type: str
@@ -121,7 +122,7 @@ class TableRow(object):
     def row_format(self):
         """Gets the row_format of this TableRow.  # noqa: E501
 
-        Gets or sets provides access to the formatting properties of the row.  # noqa: E501
+        Gets or sets the formatting properties of a row.  # noqa: E501
 
         :return: The row_format of this TableRow.  # noqa: E501
         :rtype: TableRowFormat
@@ -132,7 +133,7 @@ class TableRow(object):
     def row_format(self, row_format):
         """Sets the row_format of this TableRow.
 
-        Gets or sets provides access to the formatting properties of the row.  # noqa: E501
+        Gets or sets the formatting properties of a row.  # noqa: E501
 
         :param row_format: The row_format of this TableRow.  # noqa: E501
         :type: TableRowFormat
@@ -143,7 +144,7 @@ class TableRow(object):
     def table_cell_list(self):
         """Gets the table_cell_list of this TableRow.  # noqa: E501
 
-        Gets or sets collection of table's rows.  # noqa: E501
+        Gets or sets the collection of rows.  # noqa: E501
 
         :return: The table_cell_list of this TableRow.  # noqa: E501
         :rtype: list[TableCell]
@@ -154,7 +155,7 @@ class TableRow(object):
     def table_cell_list(self, table_cell_list):
         """Sets the table_cell_list of this TableRow.
 
-        Gets or sets collection of table's rows.  # noqa: E501
+        Gets or sets the collection of rows.  # noqa: E501
 
         :param table_cell_list: The table_cell_list of this TableRow.  # noqa: E501
         :type: list[TableCell]
@@ -168,21 +169,25 @@ class TableRow(object):
 
         for attr, _ in six.iteritems(self.swagger_types):
             value = getattr(self, attr)
+            if value is None:
+                continue
             if isinstance(value, list):
-                result[attr] = list(map(
+                result[self.attribute_map[attr]] = list(map(
                     lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                     value
                 ))
             elif hasattr(value, "to_dict"):
-                result[attr] = value.to_dict()
+                result[self.attribute_map[attr]] = value.to_dict()
             elif isinstance(value, dict):
-                result[attr] = dict(map(
+                result[self.attribute_map[attr]] = dict(map(
                     lambda item: (item[0], item[1].to_dict())
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
-                result[attr] = value
+                result[self.attribute_map[attr]] = value
 
         return result
 
@@ -205,6 +210,8 @@ class TableRow(object):
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
                 result[self.attribute_map[attr]] = value
 
