@@ -44,11 +44,13 @@ class WordMLSaveOptionsData(object):
     """
     swagger_types = {
         'allow_embedding_post_script_fonts': 'bool',
+        'custom_time_zone_info_data': 'TimeZoneInfoData',
         'dml3_d_effects_rendering_mode': 'str',
         'dml_effects_rendering_mode': 'str',
         'dml_rendering_mode': 'str',
         'file_name': 'str',
         'save_format': 'str',
+        'update_created_time_property': 'bool',
         'update_fields': 'bool',
         'update_last_printed_property': 'bool',
         'update_last_saved_time_property': 'bool',
@@ -59,11 +61,13 @@ class WordMLSaveOptionsData(object):
 
     attribute_map = {
         'allow_embedding_post_script_fonts': 'AllowEmbeddingPostScriptFonts',
+        'custom_time_zone_info_data': 'CustomTimeZoneInfoData',
         'dml3_d_effects_rendering_mode': 'Dml3DEffectsRenderingMode',
         'dml_effects_rendering_mode': 'DmlEffectsRenderingMode',
         'dml_rendering_mode': 'DmlRenderingMode',
         'file_name': 'FileName',
         'save_format': 'SaveFormat',
+        'update_created_time_property': 'UpdateCreatedTimeProperty',
         'update_fields': 'UpdateFields',
         'update_last_printed_property': 'UpdateLastPrintedProperty',
         'update_last_saved_time_property': 'UpdateLastSavedTimeProperty',
@@ -72,15 +76,17 @@ class WordMLSaveOptionsData(object):
         'pretty_format': 'PrettyFormat'
     }
 
-    def __init__(self, allow_embedding_post_script_fonts=None, dml3_d_effects_rendering_mode=None, dml_effects_rendering_mode=None, dml_rendering_mode=None, file_name=None, save_format=None, update_fields=None, update_last_printed_property=None, update_last_saved_time_property=None, update_sdt_content=None, zip_output=None, pretty_format=None):  # noqa: E501
+    def __init__(self, allow_embedding_post_script_fonts=None, custom_time_zone_info_data=None, dml3_d_effects_rendering_mode=None, dml_effects_rendering_mode=None, dml_rendering_mode=None, file_name=None, save_format=None, update_created_time_property=None, update_fields=None, update_last_printed_property=None, update_last_saved_time_property=None, update_sdt_content=None, zip_output=None, pretty_format=None):  # noqa: E501
         """WordMLSaveOptionsData - a model defined in Swagger"""  # noqa: E501
 
         self._allow_embedding_post_script_fonts = None
+        self._custom_time_zone_info_data = None
         self._dml3_d_effects_rendering_mode = None
         self._dml_effects_rendering_mode = None
         self._dml_rendering_mode = None
         self._file_name = None
         self._save_format = None
+        self._update_created_time_property = None
         self._update_fields = None
         self._update_last_printed_property = None
         self._update_last_saved_time_property = None
@@ -91,6 +97,8 @@ class WordMLSaveOptionsData(object):
 
         if allow_embedding_post_script_fonts is not None:
             self.allow_embedding_post_script_fonts = allow_embedding_post_script_fonts
+        if custom_time_zone_info_data is not None:
+            self.custom_time_zone_info_data = custom_time_zone_info_data
         if dml3_d_effects_rendering_mode is not None:
             self.dml3_d_effects_rendering_mode = dml3_d_effects_rendering_mode
         if dml_effects_rendering_mode is not None:
@@ -101,6 +109,8 @@ class WordMLSaveOptionsData(object):
             self.file_name = file_name
         if save_format is not None:
             self.save_format = save_format
+        if update_created_time_property is not None:
+            self.update_created_time_property = update_created_time_property
         if update_fields is not None:
             self.update_fields = update_fields
         if update_last_printed_property is not None:
@@ -136,6 +146,28 @@ class WordMLSaveOptionsData(object):
         """
         self._allow_embedding_post_script_fonts = allow_embedding_post_script_fonts
 
+    @property
+    def custom_time_zone_info_data(self):
+        """Gets the custom_time_zone_info_data of this WordMLSaveOptionsData.  # noqa: E501
+
+        Gets or sets CustomTimeZoneInfo.  # noqa: E501
+
+        :return: The custom_time_zone_info_data of this WordMLSaveOptionsData.  # noqa: E501
+        :rtype: TimeZoneInfoData
+        """
+        return self._custom_time_zone_info_data
+
+    @custom_time_zone_info_data.setter
+    def custom_time_zone_info_data(self, custom_time_zone_info_data):
+        """Sets the custom_time_zone_info_data of this WordMLSaveOptionsData.
+
+        Gets or sets CustomTimeZoneInfo.  # noqa: E501
+
+        :param custom_time_zone_info_data: The custom_time_zone_info_data of this WordMLSaveOptionsData.  # noqa: E501
+        :type: TimeZoneInfoData
+        """
+        self._custom_time_zone_info_data = custom_time_zone_info_data
+
     @property
     def dml3_d_effects_rendering_mode(self):
         """Gets the dml3_d_effects_rendering_mode of this WordMLSaveOptionsData.  # noqa: E501
@@ -254,6 +286,28 @@ class WordMLSaveOptionsData(object):
         """
         self._save_format = save_format
 
+    @property
+    def update_created_time_property(self):
+        """Gets the update_created_time_property of this WordMLSaveOptionsData.  # noqa: E501
+
+        Gets or sets a value determining whether the Aspose.Words.Properties.BuiltInDocumentProperties.CreatedTime property is updated before saving. Default value is false.  # noqa: E501
+
+        :return: The update_created_time_property of this WordMLSaveOptionsData.  # noqa: E501
+        :rtype: bool
+        """
+        return self._update_created_time_property
+
+    @update_created_time_property.setter
+    def update_created_time_property(self, update_created_time_property):
+        """Sets the update_created_time_property of this WordMLSaveOptionsData.
+
+        Gets or sets a value determining whether the Aspose.Words.Properties.BuiltInDocumentProperties.CreatedTime property is updated before saving. Default value is false.  # noqa: E501
+
+        :param update_created_time_property: The update_created_time_property of this WordMLSaveOptionsData.  # noqa: E501
+        :type: bool
+        """
+        self._update_created_time_property = update_created_time_property
+
     @property
     def update_fields(self):
         """Gets the update_fields of this WordMLSaveOptionsData.  # noqa: E501
